@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.1709 2025/04/14 20:05:29 kn Exp $
+# $OpenBSD: Quirks.pm,v 1.1710 2025/04/24 09:52:40 landry Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -1247,6 +1247,7 @@ setup_obsolete_reason(
 	5 => 'pycha',
 	10 => 'gotosocial',
 	5 => 'xsd',
+	29 => 'fastnetmon',
 );
 
 # though it's not yet used, these should be pkgnames, so that eventually
